<?php
/*
Plugin Name: Download Counter
Plugin URI: http://colorsin.com/index.php/2013/03/03/download-counter-bbcode-plugin-for-flatpress/
Description: Adds a download counter bbcode with URL link
Author: Igor Kromin
Version: 1.3
Author URI: http://www.colorsin.com/
*/ 
 
// this tells FlatPress to load the new tags at the very beginning
add_filter('init', 'plugin_bbcode_downloadctr_tag');
 
// define function. In this case we're creating an "inc" tag
 
function plugin_bbcode_downloadctr_tag() {
    $bbcode = plugin_bbcode_init(); //import the "global" bbcode object into current function
                                        // this way 
                                        // a) parsing is done only once, and by the official plugin
                                        // b) you create only ONE object, and therefore computation is quicker
    $bbcode->addCode (
                'download',                             // tag name: this will go between square brackets
                'callback_replace_single',              // type of action: we'll use a callback function
                'plugin_colorsin_downloadctr',      // name of the callback function
                array('usecontent_param' => array ('default', 'name', 'size')), // supported parameters: "default" is [inc=valore]
                'inline',                               // type of the tag, inline or block, etc
                array ('listitem', 'block', 'inline'),  // type of elements in which you can use this tag
                array ());                        // type of elements where this tag CAN'T go (in this case, none, so it can go everywhere)

    $bbcode->setCodeFlag ('download', 'closetag', BBCODE_CLOSETAG_FORBIDDEN); // a closing tag is forbidden (no [/tag])
}

function plugin_colorsin_calc($file) {

	$f = $file . '.dlctr'; // counter file is in the same location as the download file
	$v = io_load_file($f);
        
	if ($v === false) {
		$v = 0;
	}
        elseif ($v < 0) {
		// file was locked. Do not increase download.
		// actually on file locks system should hang, so
		// this should never happen
		$v = 0;
	}
	
	return $v;
}

function plugin_colorsin_downloadctr($action, $attr, $content, $params, $node_object) {

	if ($action == 'validate') {
		return true;
	}
        
        // files to download are assumed to be in the fp-content/attachs directory
        $file = $attr['default'];
        $download = ATTACHS_DIR . $file;
        
        // set the name to the provided name or just use the file as the name
        if (isset($attr['name'])) {
            $name = $attr['name'];
        }
        else {
            $name = $attr['default'];
        }
	
        // calculate the download count
        $ctr = plugin_colorsin_calc($download);
        $dl = ($ctr == 1) ? "download" : "downloads";
        
        // if the size attribute is set, display the size
        if (isset($attr['size'])) {
            
            $fsize = filesize($download);
            
            // if there is an error, set file size to -1
            if ($fsize === FALSE) {
                $fsize = -1;
            }
            
            switch ($attr['size']) {
                case "k":
                case "K":
                    $fs = round($fsize / 1024, 2) . " Kb"; break;
                case "m":
                case "M":
                    $fs = round($fsize / (1024 * 1024), 2) . " Mb"; break;
                case "g":
                case "G":
                    $fs = round($fsize / (1024 * 1024 * 1024), 2) . " Gb"; break;
                case "t":
                case "T":
                    $fs = round($fsize / (1024 * 1024 * 1024 * 1024), 2) . " Tb"; break;
                case "b":
                case "B":
                    $fs = $fsize . " bytes"; break;
            }
            
            $size = " [" . $fs . "]";
        }
        else {
            $size = "";
        }
        
	return '<a href="' . BLOG_BASEURL . PLUGINS_DIR . 'downloadctr/res/download.php?x=' . urlencode($file) . '">' . $name . $size . ' (' . $ctr . ' '. $dl . ')</a>';
}

?>